import 'package:flutter/material.dart';

import 'package:dynamic_color/dynamic_color.dart';
import 'package:flutter/scheduler.dart';

import 'MediumSizedContainer.dart';
import 'NavBar.dart';

void main() {
  runApp(const MainApp());
}

class MainApp extends StatelessWidget {
  const MainApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(home: DynamicColorBuilder(
        builder: (ColorScheme? lightDynamic, ColorScheme? darkDynamic) {
      final Brightness brightness =
          SchedulerBinding.instance.platformDispatcher.platformBrightness;

      final bool isDark = brightness == Brightness.dark;

      Color accentColor = (isDark
          ? (darkDynamic?.primary ?? Colors.grey.shade800)
          : (lightDynamic?.primary ?? Colors.grey.shade200));

      Color secondaryColor = (!isDark
          ? (darkDynamic?.secondary ?? Colors.red.shade800)
          : (lightDynamic?.secondary ?? Colors.blue.shade200));

      return LayoutBuilder(builder: (context, constraints) {

         return Scaffold(
          appBar: AppBar(
              title: const Text('Inpu\'s Touch'),
              backgroundColor: secondaryColor,
              foregroundColor: isDark ? Colors.white : Colors.black),
          backgroundColor: accentColor,
          bottomNavigationBar: NavBar(),
          body: constraints.maxWidth > 600 ? MediumSizedContainer(
                isItVeryLargeScreen: constraints.maxWidth >= 1200,
              )
            : const SmallSizedContainer());}
      );
         
    }));
  }
}

class SmallSizedContainer extends StatelessWidget{
  const SmallSizedContainer();
  
  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Column();
  }
}
